Package: tdaunif
Title: Uniform Manifold Samplers for Topological Data Analysis
Version: 0.2.0
Authors@R: c(
    person("Jason Cory", "Brunson", email = "cornelioid@gmail.com", role = c("aut", "cre")),
    person("Brandon", "Demkowicz", email = "brandondemkowicz@gmail.com", role = "aut"),
    person("Sanmati", "Choudhary", email = "20choudharysa@fpsct.org", role = "aut"),
    person("Barry W.", "Brunson", role = "ctb")
    )
Description: Uniform random samples from simple manifolds, sometimes with noise,
    are commonly used to test topological data analytic (TDA) tools.
    This package includes samplers powered by two techniques: analytic
    volume-preserving parameterizations, as employed by Arvo (1995)
    <doi:10.1145/218380.218500>, and rejection sampling, as employed by
    Diaconis, Holmes, and Shahshahani (2013) <doi:10.1214/12-IMSCOLL1006>.
Depends: R (>= 3.3.0)
Suggests: knitr, rmarkdown, testthat, vdiffr (>= 0.2)
License: GPL-3
Encoding: UTF-8
URL: https://tdaverse.github.io/tdaunif/
BugReports: https://github.com/tdaverse/tdaunif/issues
VignetteBuilder: knitr
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2024-06-17 17:06:06 UTC; jason.brunson
Author: Jason Cory Brunson [aut, cre],
  Brandon Demkowicz [aut],
  Sanmati Choudhary [aut],
  Barry W. Brunson [ctb]
Maintainer: Jason Cory Brunson <cornelioid@gmail.com>
Repository: CRAN
Date/Publication: 2024-06-17 17:50:02 UTC
Built: R 4.3.3; ; 2025-01-24 13:17:32 UTC; unix
