# Generated by roxygen2: do not edit by hand

export(add_noise)
export(make_rejection_sampler)
export(sample_2hemisphere)
export(sample_2sphere)
export(sample_annulus)
export(sample_arch_spiral)
export(sample_circle)
export(sample_circles_interlocked)
export(sample_cylinder_elliptical)
export(sample_disk)
export(sample_ellipse)
export(sample_klein_flat)
export(sample_klein_tube)
export(sample_lemniscate_gerono)
export(sample_mobius_rotoid)
export(sample_projective_plane)
export(sample_sphere)
export(sample_strat_cube)
export(sample_strat_segment)
export(sample_strat_square)
export(sample_stratify)
export(sample_swiss_roll)
export(sample_tori_interlocked)
export(sample_torus_flat)
export(sample_torus_tube)
export(sample_trefoil)
export(sample_triangle_planar)
importFrom(stats,runif)
